==> pacredir-debug-0.7.6-1-x86_64.pkg.tar.zst: usr/src/debug/pacredir/pacredir/favicon.h <==
#ifndef FAVICON_H
#define FAVICON_H
static unsigned char favicon[] = {
 0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d, 0x49, 0x48, 0x44, 0x52,
 0x00, 0x00, 0x00, 0x20, 0x00, 0x00, 0x00, 0x20, 0x08, 0x03, 0x00, 0x00, 0x00, 0x44, 0xa4, 0x8a,
 0xc6, 0x00, 0x00, 0x01, 0x0e, 0x50, 0x4c, 0x54, 0x45, 0xff, 0xff, 0xff, 0x00, 0x00, 0x00, 0xff,
 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xef, 0xef,
 0xdf, 0xdf, 0xdf, 0xcf, 0xcf, 0xcf, 0xff, 0xcc, 0x00, 0xbf, 0xbf, 0xbf, 0xef, 0xbf, 0x00, 0xb3,
 0xb3, 0xb3, 0xaf, 0xaf, 0xaf, 0xdf, 0xb2, 0x00, 0xd1, 0xa7, 0x00, 0x9f, 0x9f, 0x9f, 0xcf, 0xa5,
 0x00, 0xbf, 0x99, 0x00, 0xdd, 0x55, 0xff, 0x8f, 0x8f, 0x8f, 0xcf, 0x50, 0xef, 0xaf, 0x8c, 0x00,
 0x80, 0x80, 0x80, 0xc1, 0x4b, 0xdf, 0x7f, 0x7f, 0x7f, 0x9f, 0x7f, 0x00, 0xb3, 0x45, 0xcf, 0x6f,
 0x6f, 0x6f, 0xa6, 0x40, 0xc0, 0xa5, 0x40, 0xbf, 0x98, 0x3b, 0xaf, 0x80, 0x66, 0x00, 0x7f, 0x66,
 0x00, 0x5f, 0x5f, 0x5f, 0x8b, 0x36, 0xa0, 0x8a, 0x35, 0x9f, 0x70, 0x5a, 0x00, 0x6f, 0x59, 0x00,
 0x50, 0x50, 0x50, 0x68, 0x53, 0x00, 0x4f, 0x4f, 0x4f, 0x60, 0x4d, 0x00, 0x6f, 0x2b, 0x80, 0x5f,
 0x4c, 0x00, 0x6e, 0x2b, 0x7f, 0x40, 0x40, 0x40, 0x60, 0x25, 0x6f, 0x3f, 0x3f, 0x3f, 0x50, 0x40,
 0x00, 0x48, 0x3a, 0x00, 0x53, 0x20, 0x60, 0x53, 0x20, 0x5f, 0x40, 0x33, 0x00, 0x30, 0x30, 0x30,
 0x2f, 0x2f, 0x2f, 0x45, 0x1b, 0x4f, 0x30, 0x27, 0x00, 0x38, 0x16, 0x40, 0x2f, 0x26, 0x00, 0x37,
 0x15, 0x3f, 0x20, 0x20, 0x20, 0x29, 0x10, 0x30, 0x29, 0x10, 0x2f, 0x20, 0x1a, 0x00, 0x18, 0x18,
 0x18, 0x1f, 0x19, 0x00, 0x1c, 0x17, 0x00, 0x1c, 0x0b, 0x20, 0x1b, 0x0b, 0x1f, 0x10, 0x10, 0x10,
 0x10, 0x10, 0x0f, 0x0f, 0x0f, 0x0f, 0x0e, 0x0e, 0x0e, 0x10, 0x0d, 0x01, 0x10, 0x0d, 0x00, 0x0f,
 0x0c, 0x00, 0x0e, 0x0c, 0x00, 0x0e, 0x0b, 0x01, 0x0e, 0x06, 0x10, 0x0e, 0x06, 0x0f, 0x0d, 0x06,
 0x0f, 0x0d, 0x05, 0x0f, 0x00, 0x00, 0x00, 0xaf, 0x41, 0x4d, 0x81, 0x00, 0x00, 0x00, 0x0c, 0x74,
 0x52, 0x4e, 0x53, 0xff, 0x00, 0x40, 0x50, 0x80, 0x90, 0xaf, 0xb0, 0xbf, 0xc0, 0xcf, 0xef, 0xc9,
 0x77, 0x8b, 0x38, 0x00, 0x00, 0x01, 0xfc, 0x49, 0x44, 0x41, 0x54, 0x78, 0xda, 0x6d, 0xd3, 0xd1,
 0x4b, 0x5a, 0x51, 0x00, 0xc7, 0xf1, 0xef, 0x39, 0xd9, 0xf2, 0x56, 0x5e, 0xbd, 0x3d, 0x64, 0x93,
 0x4c, 0x5a, 0x69, 0x56, 0x56, 0xcc, 0x9c, 0x10, 0x38, 0x18, 0x7b, 0x28, 0x06, 0xd6, 0xc0, 0x3d,
 0x9d, 0xbf, 0x74, 0xaf, 0xb2, 0x8d, 0xd1, 0x5e, 0x62, 0x23, 0x9c, 0xcc, 0xe1, 0x4c, 0xac, 0x66,
 0xae, 0xd1, 0xd0, 0x2e, 0xcd, 0xc5, 0x2e, 0xbb, 0xbb, 0x1e, 0x2e, 0x97, 0xe8, 0xf3, 0x76, 0xce,
 0xef, 0xfb, 0x70, 0x5e, 0x0e, 0x42, 0xc8, 0x07, 0x53, 0xdc, 0x2f, 0x2c, 0x85, 0x40, 0x8c, 0xa3,
 0xc5, 0x92, 0x85, 0xb2, 0x52, 0xe5, 0x42, 0xd2, 0xc4, 0x17, 0x12, 0x8c, 0xa1, 0xe7, 0x82, 0xf2,
 0x15, 0x62, 0xa0, 0x49, 0x26, 0x01, 0x30, 0xdd, 0xb9, 0x92, 0x9b, 0xb7, 0xa2, 0x51, 0x6b, 0x3e,
 0x57, 0x51, 0x6a, 0x23, 0xc2, 0x88, 0x81, 0xc7, 0x2c, 0xab, 0xca, 0x8a, 0x15, 0xd5, 0xac, 0x95,
 0x8a, 0x2a, 0x9b, 0x04, 0x98, 0xfb, 0x2a, 0xaf, 0x67, 0x9d, 0xe4, 0xd5, 0x7e, 0xa0, 0x88, 0x94,
 0x55, 0xde, 0xbd, 0x5c, 0xdf, 0xdd, 0xcd, 0xf8, 0x49, 0x5e, 0x95, 0x23, 0xa0, 0x15, 0xfe, 0xef,
 0xd1, 0x9c, 0x72, 0xe5, 0xa2, 0x5a, 0x5c, 0xa9, 0xac, 0x7e, 0x25, 0xb1, 0xf4, 0xb0, 0x05, 0xa4,
 0x01, 0x12, 0x8c, 0xc4, 0x9f, 0x73, 0x7a, 0x0e, 0x40, 0x08, 0x96, 0xa9, 0x39, 0x80, 0xd0, 0x3d,
 0x30, 0xbe, 0xb2, 0xc0, 0x87, 0x6f, 0x78, 0x24, 0x66, 0x7a, 0xd8, 0x03, 0xa8, 0x01, 0xb4, 0x00,
 0xac, 0xa7, 0x0b, 0xf6, 0x6b, 0xbd, 0x13, 0xc2, 0xa2, 0xe1, 0x00, 0x74, 0x8f, 0xe7, 0x69, 0x75,
 0x41, 0x66, 0x1e, 0xf1, 0xb9, 0x79, 0x8d, 0x1f, 0x18, 0xe8, 0x43, 0xa7, 0x03, 0x60, 0xec, 0x84,
 0xed, 0xc3, 0x1e, 0xe0, 0x07, 0x26, 0xbf, 0xf1, 0xc9, 0xc4, 0x26, 0xcd, 0xfa, 0x80, 0x60, 0x30,
 0xcb, 0x10, 0xdf, 0x66, 0x82, 0xf7, 0x6d, 0x82, 0x24, 0x92, 0x00, 0x09, 0x0e, 0x77, 0x82, 0x2e,
 0x13, 0xf8, 0x3e, 0x1e, 0x53, 0xda, 0x7b, 0xa9, 0x52, 0xc1, 0xa0, 0x4f, 0x18, 0x9f, 0xd3, 0x6d,
 0x31, 0x63, 0x38, 0x1b, 0xc1, 0xe0, 0x86, 0x69, 0x7c, 0xf1, 0xd2, 0xe2, 0xdf, 0xc6, 0xdb, 0xef,
 0x91, 0x99, 0xc0, 0x23, 0xaf, 0x48, 0x9f, 0x39, 0x78, 0xc2, 0xd9, 0x04, 0xed, 0xb6, 0x83, 0xcd,
 0x1e, 0xc0, 0xd7, 0x8b, 0x0e, 0x08, 0x28, 0x2e, 0x1d, 0x75, 0x01, 0x88, 0x6f, 0xd3, 0xff, 0x62,
 0x03, 0x89, 0x0c, 0x23, 0x9d, 0x77, 0x48, 0x68, 0xb0, 0x26, 0x01, 0x99, 0xdb, 0xa6, 0x71, 0x64,
 0xe3, 0x69, 0x54, 0xab, 0xd5, 0x37, 0x9f, 0x2e, 0x93, 0x29, 0x24, 0xfc, 0x6a, 0x86, 0x53, 0x20,
 0x37, 0x17, 0x2e, 0x0f, 0xcf, 0xf1, 0xdc, 0x20, 0x01, 0xe7, 0xea, 0x84, 0x24, 0x21, 0xa0, 0x3e,
 0xb7, 0x4a, 0x2b, 0x9a, 0xb8, 0xa8, 0xa3, 0xfd, 0x21, 0x02, 0xc0, 0x35, 0x49, 0x2f, 0x1d, 0x54,
 0xed, 0xd5, 0x45, 0x9b, 0xf8, 0x1c, 0x77, 0x58, 0x34, 0xbd, 0x80, 0xbe, 0x5b, 0x94, 0x6a, 0xb7,
 0xd9, 0xc7, 0x53, 0x68, 0x72, 0xd2, 0x15, 0x5b, 0xe7, 0x14, 0xcd, 0x2c, 0x2a, 0xf5, 0xea, 0x85,
 0x52, 0xcf, 0x96, 0x1f, 0xba, 0x96, 0x95, 0x96, 0x05, 0x81, 0x16, 0xcb, 0x2c, 0x01, 0x70, 0x72,
 0x76, 0xcb, 0xd4, 0x93, 0xde, 0x00, 0xe8, 0xff, 0xf8, 0x09, 0x18, 0xa0, 0x99, 0xa9, 0xe2, 0x81,
 0x72, 0xed, 0x2c, 0xae, 0xa9, 0x14, 0xda, 0x04, 0x63, 0x10, 0x34, 0x9d, 0xf2, 0xa2, 0x18, 0x9a,
 0xd4, 0x9f, 0x37, 0x98, 0xcc, 0x6e, 0x1d, 0x6c, 0x05, 0x3e, 0xaf, 0x10, 0xd2, 0x80, 0xfb, 0x19,
 0x52, 0x88, 0x7f, 0x75, 0x57, 0x93, 0x33, 0xe0, 0x3a, 0xf6, 0xff, 0x00, 0x00, 0x00, 0x00, 0x49,
 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82,
};
#define FAVICON_SHA1 "3e67627f7ae3e0d06b16cfb5fc302e742c69b05b"
#define FAVICON_DATE "Mon, 01 Sep 2025 15:50:55 GMT"
#endif

==> pacredir-debug-0.7.7-1-x86_64.pkg.tar.zst: usr/src/debug/pacredir/pacredir/favicon.h <==
#ifndef FAVICON_H
#define FAVICON_H
static unsigned char favicon[] = {
 0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d, 0x49, 0x48, 0x44, 0x52,
 0x00, 0x00, 0x00, 0x20, 0x00, 0x00, 0x00, 0x20, 0x08, 0x03, 0x00, 0x00, 0x00, 0x44, 0xa4, 0x8a,
 0xc6, 0x00, 0x00, 0x01, 0x0e, 0x50, 0x4c, 0x54, 0x45, 0xff, 0xff, 0xff, 0x00, 0x00, 0x00, 0xff,
 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xef, 0xef,
 0xdf, 0xdf, 0xdf, 0xcf, 0xcf, 0xcf, 0xff, 0xcc, 0x00, 0xbf, 0xbf, 0xbf, 0xef, 0xbf, 0x00, 0xb3,
 0xb3, 0xb3, 0xaf, 0xaf, 0xaf, 0xdf, 0xb2, 0x00, 0xd1, 0xa7, 0x00, 0x9f, 0x9f, 0x9f, 0xcf, 0xa5,
 0x00, 0xbf, 0x99, 0x00, 0xdd, 0x55, 0xff, 0x8f, 0x8f, 0x8f, 0xcf, 0x50, 0xef, 0xaf, 0x8c, 0x00,
 0x80, 0x80, 0x80, 0xc1, 0x4b, 0xdf, 0x7f, 0x7f, 0x7f, 0x9f, 0x7f, 0x00, 0xb3, 0x45, 0xcf, 0x6f,
 0x6f, 0x6f, 0xa6, 0x40, 0xc0, 0xa5, 0x40, 0xbf, 0x98, 0x3b, 0xaf, 0x80, 0x66, 0x00, 0x7f, 0x66,
 0x00, 0x5f, 0x5f, 0x5f, 0x8b, 0x36, 0xa0, 0x8a, 0x35, 0x9f, 0x70, 0x5a, 0x00, 0x6f, 0x59, 0x00,
 0x50, 0x50, 0x50, 0x68, 0x53, 0x00, 0x4f, 0x4f, 0x4f, 0x60, 0x4d, 0x00, 0x6f, 0x2b, 0x80, 0x5f,
 0x4c, 0x00, 0x6e, 0x2b, 0x7f, 0x40, 0x40, 0x40, 0x60, 0x25, 0x6f, 0x3f, 0x3f, 0x3f, 0x50, 0x40,
 0x00, 0x48, 0x3a, 0x00, 0x53, 0x20, 0x60, 0x53, 0x20, 0x5f, 0x40, 0x33, 0x00, 0x30, 0x30, 0x30,
 0x2f, 0x2f, 0x2f, 0x45, 0x1b, 0x4f, 0x30, 0x27, 0x00, 0x38, 0x16, 0x40, 0x2f, 0x26, 0x00, 0x37,
 0x15, 0x3f, 0x20, 0x20, 0x20, 0x29, 0x10, 0x30, 0x29, 0x10, 0x2f, 0x20, 0x1a, 0x00, 0x18, 0x18,
 0x18, 0x1f, 0x19, 0x00, 0x1c, 0x17, 0x00, 0x1c, 0x0b, 0x20, 0x1b, 0x0b, 0x1f, 0x10, 0x10, 0x10,
 0x10, 0x10, 0x0f, 0x0f, 0x0f, 0x0f, 0x0e, 0x0e, 0x0e, 0x10, 0x0d, 0x01, 0x10, 0x0d, 0x00, 0x0f,
 0x0c, 0x00, 0x0e, 0x0c, 0x00, 0x0e, 0x0b, 0x01, 0x0e, 0x06, 0x10, 0x0e, 0x06, 0x0f, 0x0d, 0x06,
 0x0f, 0x0d, 0x05, 0x0f, 0x00, 0x00, 0x00, 0xaf, 0x41, 0x4d, 0x81, 0x00, 0x00, 0x00, 0x0c, 0x74,
 0x52, 0x4e, 0x53, 0xff, 0x00, 0x40, 0x50, 0x80, 0x90, 0xaf, 0xb0, 0xbf, 0xc0, 0xcf, 0xef, 0xc9,
 0x77, 0x8b, 0x38, 0x00, 0x00, 0x01, 0xfc, 0x49, 0x44, 0x41, 0x54, 0x78, 0xda, 0x6d, 0xd3, 0xd1,
 0x4b, 0x5a, 0x51, 0x00, 0xc7, 0xf1, 0xef, 0x39, 0xd9, 0xf2, 0x56, 0x5e, 0xbd, 0x3d, 0x64, 0x93,
 0x4c, 0x5a, 0x69, 0x56, 0x56, 0xcc, 0x9c, 0x10, 0x38, 0x18, 0x7b, 0x28, 0x06, 0xd6, 0xc0, 0x3d,
 0x9d, 0xbf, 0x74, 0xaf, 0xb2, 0x8d, 0xd1, 0x5e, 0x62, 0x23, 0x9c, 0xcc, 0xe1, 0x4c, 0xac, 0x66,
 0xae, 0xd1, 0xd0, 0x2e, 0xcd, 0xc5, 0x2e, 0xbb, 0xbb, 0x1e, 0x2e, 0x97, 0xe8, 0xf3, 0x76, 0xce,
 0xef, 0xfb, 0x70, 0x5e, 0x0e, 0x42, 0xc8, 0x07, 0x53, 0xdc, 0x2f, 0x2c, 0x85, 0x40, 0x8c, 0xa3,
 0xc5, 0x92, 0x85, 0xb2, 0x52, 0xe5, 0x42, 0xd2, 0xc4, 0x17, 0x12, 0x8c, 0xa1, 0xe7, 0x82, 0xf2,
 0x15, 0x62, 0xa0, 0x49, 0x26, 0x01, 0x30, 0xdd, 0xb9, 0x92, 0x9b, 0xb7, 0xa2, 0x51, 0x6b, 0x3e,
 0x57, 0x51, 0x6a, 0x23, 0xc2, 0x88, 0x81, 0xc7, 0x2c, 0xab, 0xca, 0x8a, 0x15, 0xd5, 0xac, 0x95,
 0x8a, 0x2a, 0x9b, 0x04, 0x98, 0xfb, 0x2a, 0xaf, 0x67, 0x9d, 0xe4, 0xd5, 0x7e, 0xa0, 0x88, 0x94,
 0x55, 0xde, 0xbd, 0x5c, 0xdf, 0xdd, 0xcd, 0xf8, 0x49, 0x5e, 0x95, 0x23, 0xa0, 0x15, 0xfe, 0xef,
 0xd1, 0x9c, 0x72, 0xe5, 0xa2, 0x5a, 0x5c, 0xa9, 0xac, 0x7e, 0x25, 0xb1, 0xf4, 0xb0, 0x05, 0xa4,
 0x01, 0x12, 0x8c, 0xc4, 0x9f, 0x73, 0x7a, 0x0e, 0x40, 0x08, 0x96, 0xa9, 0x39, 0x80, 0xd0, 0x3d,
 0x30, 0xbe, 0xb2, 0xc0, 0x87, 0x6f, 0x78, 0x24, 0x66, 0x7a, 0xd8, 0x03, 0xa8, 0x01, 0xb4, 0x00,
 0xac, 0xa7, 0x0b, 0xf6, 0x6b, 0xbd, 0x13, 0xc2, 0xa2, 0xe1, 0x00, 0x74, 0x8f, 0xe7, 0x69, 0x75,
 0x41, 0x66, 0x1e, 0xf1, 0xb9, 0x79, 0x8d, 0x1f, 0x18, 0xe8, 0x43, 0xa7, 0x03, 0x60, 0xec, 0x84,
 0xed, 0xc3, 0x1e, 0xe0, 0x07, 0x26, 0xbf, 0xf1, 0xc9, 0xc4, 0x26, 0xcd, 0xfa, 0x80, 0x60, 0x30,
 0xcb, 0x10, 0xdf, 0x66, 0x82, 0xf7, 0x6d, 0x82, 0x24, 0x92, 0x00, 0x09, 0x0e, 0x77, 0x82, 0x2e,
 0x13, 0xf8, 0x3e, 0x1e, 0x53, 0xda, 0x7b, 0xa9, 0x52, 0xc1, 0xa0, 0x4f, 0x18, 0x9f, 0xd3, 0x6d,
 0x31, 0x63, 0x38, 0x1b, 0xc1, 0xe0, 0x86, 0x69, 0x7c, 0xf1, 0xd2, 0xe2, 0xdf, 0xc6, 0xdb, 0xef,
 0x91, 0x99, 0xc0, 0x23, 0xaf, 0x48, 0x9f, 0x39, 0x78, 0xc2, 0xd9, 0x04, 0xed, 0xb6, 0x83, 0xcd,
 0x1e, 0xc0, 0xd7, 0x8b, 0x0e, 0x08, 0x28, 0x2e, 0x1d, 0x75, 0x01, 0x88, 0x6f, 0xd3, 0xff, 0x62,
 0x03, 0x89, 0x0c, 0x23, 0x9d, 0x77, 0x48, 0x68, 0xb0, 0x26, 0x01, 0x99, 0xdb, 0xa6, 0x71, 0x64,
 0xe3, 0x69, 0x54, 0xab, 0xd5, 0x37, 0x9f, 0x2e, 0x93, 0x29, 0x24, 0xfc, 0x6a, 0x86, 0x53, 0x20,
 0x37, 0x17, 0x2e, 0x0f, 0xcf, 0xf1, 0xdc, 0x20, 0x01, 0xe7, 0xea, 0x84, 0x24, 0x21, 0xa0, 0x3e,
 0xb7, 0x4a, 0x2b, 0x9a, 0xb8, 0xa8, 0xa3, 0xfd, 0x21, 0x02, 0xc0, 0x35, 0x49, 0x2f, 0x1d, 0x54,
 0xed, 0xd5, 0x45, 0x9b, 0xf8, 0x1c, 0x77, 0x58, 0x34, 0xbd, 0x80, 0xbe, 0x5b, 0x94, 0x6a, 0xb7,
 0xd9, 0xc7, 0x53, 0x68, 0x72, 0xd2, 0x15, 0x5b, 0xe7, 0x14, 0xcd, 0x2c, 0x2a, 0xf5, 0xea, 0x85,
 0x52, 0xcf, 0x96, 0x1f, 0xba, 0x96, 0x95, 0x96, 0x05, 0x81, 0x16, 0xcb, 0x2c, 0x01, 0x70, 0x72,
 0x76, 0xcb, 0xd4, 0x93, 0xde, 0x00, 0xe8, 0xff, 0xf8, 0x09, 0x18, 0xa0, 0x99, 0xa9, 0xe2, 0x81,
 0x72, 0xed, 0x2c, 0xae, 0xa9, 0x14, 0xda, 0x04, 0x63, 0x10, 0x34, 0x9d, 0xf2, 0xa2, 0x18, 0x9a,
 0xd4, 0x9f, 0x37, 0x98, 0xcc, 0x6e, 0x1d, 0x6c, 0x05, 0x3e, 0xaf, 0x10, 0xd2, 0x80, 0xfb, 0x19,
 0x52, 0x88, 0x7f, 0x75, 0x57, 0x93, 0x33, 0xe0, 0x3a, 0xf6, 0xff, 0x00, 0x00, 0x00, 0x00, 0x49,
 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82,
};
#define FAVICON_SHA1 "3e67627f7ae3e0d06b16cfb5fc302e742c69b05b"
#define FAVICON_DATE "Fri, 12 Dec 2025 10:46:44 GMT"
#endif
